package it.mokabyte.pattern.client;

import javax.naming.*;
import javax.rmi.PortableRemoteObject;
import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import java.rmi.RemoteException;

import it.mokabyte.pattern.ejb.entity.Account;
import it.mokabyte.pattern.ejb.entity.AccountHome;
import it.mokabyte.pattern.pk.AccountPK;
import it.mokabyte.pattern.valueobject.AccountOM;

/**
 * <p>Title:AccountTestClient </p>
 * <p>Description: simple test for Entity Account EJB </p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author Rossini S. - Dozio L.
 * @version 1.0
 */
public class AccountTestClient {

    /** EJB JNDI name */
    private final static String EJB_NAME = "MokaAccount";

    /** main */
    public static void main(String[] args) {
        System.out.println("starting AccountTestClient ...");
        new AccountTestClient().test();
    }

    /** Test the Entity EJB Account */
    public void test() {
      try {
          Context ctx = null;
          ctx =  new InitialContext();
          System.out.println("Lookup for ["+this.EJB_NAME+"]...");
          //look up jndi name
          Object obj = ctx.lookup(this.EJB_NAME);
          System.out.println("Lookup done : obj class["+obj.getClass().getName()+"] ...");
          System.out.println("Lookup done : obj ["+obj+"] ...");
          //cast to Home interface
          AccountHome accountHome = (AccountHome)PortableRemoteObject.narrow(obj, AccountHome.class);
          System.out.println("Narrow done ...accountHome["+accountHome+"]...");
          // start the test
          // create an account
          System.out.println("creating a test account ...");
          Account account = accountHome.create("004","Java Duke","duke@hero.com",0);
          System.out.println("creating done, find by primary key ...");
          // check : find by primary key what has been yet created
          account = accountHome.findByPrimaryKey(new AccountPK("004"));
          // read data
          System.out.println("calling accessors EJB methods ...");
          System.out.println("Balance ...  : " + account.getBalance());
          System.out.println("Name ......  : " + account.getName());
          System.out.println("Email .... . : " + account.getEmail());

          // update Name
          account.setName("Aran");
          // read new name value
          System.out.println("New name ...  : " + account.getName());

          // update email
          account.setEmail("aran@dog.bone");
          // read new email value
          System.out.println("New email ...  : " + account.getEmail());

          // update balance
          account.setBalance(1234.567);
          // read new balance value
          System.out.println("New Balance ...  : " + account.getBalance());

          // remove account so the test can be performed again
          account.remove();
        } catch(ClassCastException cce) {
            System.out.println(" # ClassCastExceptionException : " + cce.getMessage());
            cce.printStackTrace();
        } catch(NamingException ne) {
            System.out.println(" # NamingException : " + ne.getMessage());
            ne.printStackTrace();
        } catch(CreateException ce) {
            System.out.println(" # CreateException : " + ce.getMessage());
            ce.printStackTrace();
        } catch(FinderException fe) {
            System.out.println(" # FinderException : " + fe.getMessage());
            fe.printStackTrace();
        } catch(RemoteException re) {
            System.out.println(" # RemoteException : " + re.getMessage());
            re.printStackTrace();
        }
        catch(RemoveException rmve) {
            System.out.println(" # RemoveException : " + rmve.getMessage());
            rmve.printStackTrace();
        }
        catch(Exception e) {
            System.out.println(" # Exception  : " + e.getMessage());
            e.printStackTrace();
        }
    }
}